//
//  PomodoroProvider.swift
//  Pomodoro
//
//  Created by Matthew Newill on 12/03/2025.
//

import WidgetKit

struct PomodoroProvider: TimelineProvider {
    func placeholder(in context: Context) -> PomodoroEntry {
        PomodoroEntry(date: Date(), timeRemaining: 1500, isRunning: false, selectedDuration: 1500)
    }

    func getSnapshot(in context: Context, completion: @escaping (PomodoroEntry) -> Void) {
        let sharedDefaults = UserDefaults(suiteName: "group.com.devfright.pomodorogroup")
        let isRunning = sharedDefaults?.bool(forKey: "isRunning") ?? false
        let timeRemaining = sharedDefaults?.integer(forKey: "timeRemaining") ?? 1500

        completion(PomodoroEntry(date: Date(), timeRemaining: timeRemaining, isRunning: isRunning, selectedDuration: 1500))
    }

    func getTimeline(in context: Context, completion: @escaping (Timeline<PomodoroEntry>) -> Void) {
        let sharedDefaults = UserDefaults(suiteName: "group.com.devfright.pomodorogroup")
        let isRunning = sharedDefaults?.bool(forKey: "isRunning") ?? false
        let timeRemaining = sharedDefaults?.integer(forKey: "timeRemaining") ?? 1500

        let entry = PomodoroEntry(date: Date(), timeRemaining: timeRemaining, isRunning: isRunning, selectedDuration: 1500)
        
        let refreshPolicy: TimelineReloadPolicy = isRunning ? .after(Date().addingTimeInterval(60)) : .after(Date().addingTimeInterval(3600))

        completion(Timeline(entries: [entry], policy: refreshPolicy))
    }
}
